@@ -173,7 +173,7 @@ struct _xmlEnumeration {
 typedef struct _xmlAttribute xmlAttribute;
 typedef xmlAttribute *xmlAttributePtr;
 struct _xmlAttribute {
-    void           *_private;	        /* for Corba, must be first ! */
+    void           *_private;	        /* application data */
     xmlElementType          type;       /* XML_ATTRIBUTE_DECL, must be second ! */
     const xmlChar          *name;	/* Attribute name */
     struct _xmlNode    *children;	/* NULL */
@@ -228,10 +228,11 @@ typedef xmlElementContent *xmlElementContentPtr;
 struct _xmlElementContent {
     xmlElementContentType     type;	/* PCDATA, ELEMENT, SEQ or OR */
     xmlElementContentOccur    ocur;	/* ONCE, OPT, MULT or PLUS */
-    const xmlChar            *name;	/* Element name */
+    const xmlChar             *name;	/* Element name */
     struct _xmlElementContent *c1;	/* first child */
     struct _xmlElementContent *c2;	/* second child */
     struct _xmlElementContent *parent;	/* parent */
+    const xmlChar             *prefix;	/* Element name */
 };
 
 /**
@@ -257,7 +258,7 @@ typedef enum {
 typedef struct _xmlElement xmlElement;
 typedef xmlElement *xmlElementPtr;
 struct _xmlElement {
-    void           *_private;	        /* for Corba, must be first ! */
+    void           *_private;	        /* application data */
     xmlElementType          type;       /* XML_ELEMENT_DECL, must be second ! */
     const xmlChar          *name;	/* Element name */
     struct _xmlNode    *children;	/* NULL */
@@ -310,7 +311,7 @@ struct _xmlNs {
 typedef struct _xmlDtd xmlDtd;
 typedef xmlDtd *xmlDtdPtr;
 struct _xmlDtd {
-    void           *_private;	/* for Corba, must be first ! */
+    void           *_private;	/* application data */
     xmlElementType  type;       /* XML_DTD_NODE, must be second ! */
     const xmlChar *name;	/* Name of the DTD */
     struct _xmlNode *children;	/* the value of the property link */
@@ -338,7 +339,7 @@ struct _xmlDtd {
 typedef struct _xmlAttr xmlAttr;
 typedef xmlAttr *xmlAttrPtr;
 struct _xmlAttr {
-    void           *_private;	/* for Corba, must be first ! */
+    void           *_private;	/* application data */
     xmlElementType   type;      /* XML_ATTRIBUTE_NODE, must be second ! */
     const xmlChar   *name;      /* the name of the property */
     struct _xmlNode *children;	/* the value of the property */
@@ -413,7 +414,7 @@ struct _xmlBuffer {
 typedef struct _xmlNode xmlNode;
 typedef xmlNode *xmlNodePtr;
 struct _xmlNode {
-    void           *_private;	/* for Corba, must be first ! */
+    void           *_private;	/* application data */
     xmlElementType   type;	/* type number, must be second ! */
     const xmlChar   *name;      /* the name of the node, or the entity */
     struct _xmlNode *children;	/* parent->childs link */
@@ -440,15 +441,17 @@ struct _xmlNode {
  * macro to extract the content pointer of a node
  */
 #define XML_GET_CONTENT(n)					\
-    ((n)->type == XML_ELEMENT_PTR ? NULL : (n)->content)
+    ((n)->type == XML_ELEMENT_NODE ? NULL : (n)->content)
 
 /**
  * XML_GET_LINE:
  *
- * macro to extract the line number of an element node
+ * macro to extract the line number of an element node. 
+ * This will work only if line numbering is activated by
+ * calling xmlLineNumbersDefault(1) before parsing
  */
 #define XML_GET_LINE(n)						\
-    ((n)->type == XML_ELEMENT_PTR ? (int) (n)->content : 0)
+    ((n)->type == XML_ELEMENT_NODE ? (int) (n)->content : 0)
 
 /**
  * xmlDoc:
@@ -458,7 +461,7 @@ struct _xmlNode {
 typedef struct _xmlDoc xmlDoc;
 typedef xmlDoc *xmlDocPtr;
 struct _xmlDoc {
-    void           *_private;	/* for Corba, must be first ! */
+    void           *_private;	/* application data */
     xmlElementType  type;       /* XML_DOCUMENT_NODE, must be second ! */
     char           *name;	/* name/filename/URI of the document */
     struct _xmlNode *children;	/* the document tree */
