@@ -27,21 +27,21 @@ extern void xmlCheckVersion(int version);
  *
  * the version string like "1.2.3"
  */
-#define LIBXML_DOTTED_VERSION "2.4.10"
+#define LIBXML_DOTTED_VERSION "2.4.11"
 
 /**
  * LIBXML_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXML_VERSION 20410
+#define LIBXML_VERSION 20411
 
 /**
  * LIBXML_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXML_VERSION_STRING "20410"
+#define LIBXML_VERSION_STRING "20411"
 
 /**
  * LIBXML_TEST_VERSION:
@@ -49,7 +49,7 @@ extern void xmlCheckVersion(int version);
  * Macro to check that the libxml version in use is compatible with
  * the version the software has been compiled against
  */
-#define LIBXML_TEST_VERSION xmlCheckVersion(20410);
+#define LIBXML_TEST_VERSION xmlCheckVersion(20411);
 
 #if 0
 /**
@@ -144,11 +144,9 @@ extern void xmlCheckVersion(int version);
  *
  * Whether iconv support is available
  */
-#if !defined(WIN32) || defined(__CYGWIN__)
 #if 0
 #define LIBXML_ICONV_ENABLED
 #endif
-#endif
 
 /**
  * LIBXML_DEBUG_ENABLED:
@@ -207,6 +205,18 @@ extern void xmlCheckVersion(int version);
 #define ATTRIBUTE_UNUSED
 #endif
 
+/**
+ * #pragma comment(lib, "iconv.lib")
+ *
+ * pragma understood my MS compiler which enables a conditional link with
+ * iconv.
+ */
+#ifdef _MSC_VER
+#if defined LIBXML_ICONV_ENABLED && !defined LIBXML2_COMPILING_MSCCDEF
+#pragma comment(lib, "iconv.lib")
+#endif
+#endif
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
